# tamr-toolbox
The Tamr Toolbox is a Python library created to provide a simple interface for common interactions with Tamr and common data workflows that include Tamr. The more specialized [Tamr Python Client](https://github.com/Datatamer/tamr-client) library is used for direct interactions with Tamr in both the development of the Tamr Toolbox and in the recommended use of the Tamr Toolbox.


## Resources
__Releases:__ https://github.com/Datatamer/tamr-toolbox/releases 

__Documentation Home:__ https://datatamer.github.io/tamr-toolbox/latest/

__Installation:__ https://datatamer.github.io/tamr-toolbox/latest/installation.html

__Examples:__ https://datatamer.github.io/tamr-toolbox/latest/examples.html

## Community Contributions
Contributions to the Tamr Toolbox are currently limited to Tamr employees only. 
Tamr does not routinely review or merge community submitted pull requests.

If you are a community member that would like to report a bug or a feature request, you may 
file a Github issue in the tamr-toolbox repository.
